@@ -8,6 +8,7 @@ use version;
 use Path::Tiny;
 use Fcntl qw/:seek/;
 use Encode;
+use String::Copyright;
 
 use Moo;
 
@@ -20,11 +21,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.9
+Version v3.0.10
 
 =cut
 
-our $VERSION = version->declare("v3.0.9");
+our $VERSION = version->declare("v3.0.10");
 
 =head1 SYNOPSIS
 
@@ -97,32 +98,6 @@ my $default_ignore_regex = q!
 	\.shelf|_MTN|\.bzr(?:\.backup|tags)?)(?:$|/.*$)
 !;
 
-# also used to cleanup
-my $copyright_indicator_regex = qr!
-	(?:copyright(?:-holders?)? # The full word (or slightly more)
-		|copr\. # Legally-valid abbreviation
-		|© # Unicode character COPYRIGHT SIGN
-		|\(c\) # Legally-null representation of sign
-	)
-!ix;
-
-my $copyright_indicator_regex_with_capture
-	= qr!$copyright_indicator_regex(?::\s*|\s+)(\S.*)$!ix;
-
-# avoid ditching things like <info@foo.com>
-my $copyright_disindicator_regex = qr{
-	\b(?:info(?:rmation)?(?!@) # Discussing copyright information
-	|(notice|statement|claim|string)s? # Discussing the notice
-	|is|in|to # Part of a sentence
-	|(holder|owner)s? # Part of a sentence
-	|ownership # Part of a sentence
-	)\b
-}ix;
-
-my $copyright_predisindicator_regex = qr!(
-	^[#]define\s+.*\(c\) # #define foo(c) -- not copyright
-)!ix;
-
 has check_regex => (
 	is     => 'rw',
 	lazy   => 1,
@@ -259,7 +234,7 @@ sub parse_file
 
 	return (
 		$self->parse_license( clean_cruft_and_spaces($cleaned_content) ),
-		extract_copyright( clean_cruft($cleaned_content) ),
+		copyright( clean_cruft($cleaned_content) ),
 	);
 }
 
@@ -294,9 +269,9 @@ sub parse_lines
 
 	my $license
 		= $self->parse_license( clean_cruft_and_spaces($cleaned_content) );
-	my $copyrights = extract_copyright( clean_cruft($cleaned_content) );
+	my $copyrights = copyright( clean_cruft($cleaned_content) );
 
-	if ( not @$copyrights and $license eq 'UNKNOWN' ) {
+	if ( not @{ $copyrights->blocks } and $license eq 'UNKNOWN' ) {
 		my $position = $fh->tell;                 # See IO::Seekable
 		my $jump     = $st->size - $self->tail;
 		$jump = $position if $jump < $position;
@@ -311,7 +286,7 @@ sub parse_lines
 
 		my $cleaned_tail = clean_comments($tail);
 
-		$copyrights = extract_copyright( clean_cruft($cleaned_tail) );
+		$copyrights = copyright( clean_cruft($cleaned_tail) );
 		$license
 			= $self->parse_license( clean_cruft_and_spaces($cleaned_tail) );
 	}
@@ -320,76 +295,6 @@ sub parse_lines
 	return ( $license, $copyrights );
 }
 
-sub extract_copyright
-{
-	my @c = split /\n/, shift;
-
-	my @copyrights;
-	my $lines_after_copyright_block = 0;
-
-	my $in_copyright_block = 0;
-	while (@c) {
-		my $line = shift @c;
-		my $copyright_match = parse_copyright( $line, \$in_copyright_block );
-		if ($copyright_match) {
-			while ( @c and $copyright_match =~ /\d[,.]?\s*$/ ) {
-
-   # looks like copyright end with a year, assume the owner is on next line(s)
-				$copyright_match .= ' ' . shift @c;
-			}
-			$copyright_match =~ s/\s+/ /g;
-			$copyright_match =~ s/\s*$//;
-			push @copyrights, $copyright_match;
-		}
-		elsif (@copyrights) {
-
- # skip remaining lines if a copyright blocks was found more than 5 lines ago.
- # so a copyright block may contain up to 5 blank lines, but no more
-			last if $lines_after_copyright_block++ > 5;
-		}
-	}
-	return \@copyrights;
-}
-
-sub parse_copyright
-{
-	my $data                   = shift;
-	my $in_copyright_block_ref = shift;
-	my $copyright              = '';
-	my $match;
-
-	if ( $data !~ $copyright_predisindicator_regex ) {
-
-		#print "match against ->$data<-\n";
-		if ( $data =~ $copyright_indicator_regex_with_capture ) {
-			$match                   = $1;
-			$$in_copyright_block_ref = 1;
-
-			# Ignore lines matching "see foo for copyright information" etc.
-			if ( $match !~ $copyright_disindicator_regex ) {
-
-				# De-cruft
-				$match =~ s/$copyright_indicator_regex//igx;
-				$match =~ s/^\s+//;
-				$match =~ s/\s*\bby\b\s*/ /;
-				$match =~ s/([,.])?\s*$//;
-				$match =~ s/\s{2,}/ /g;
-				$copyright = $match;
-			}
-		}
-		elsif ( $$in_copyright_block_ref and $data =~ /^\d{2,}[,\s]+/ ) {
-
-			# following lines beginning with a year are supposed to be
-			# continued copyright blocks
-			$copyright = $data;
-		}
-		else {
-			$$in_copyright_block_ref = 0;
-		}
-	}
-	return $copyright;
-}
-
 sub clean_comments
 {
 	local $_ = shift or return q{};
